@@ -1,5 +1,7 @@
 from dataclasses import dataclass
 from typing import Any
+from typing import Dict
+from typing import List
 from typing import Union
 
 
@@ -11,9 +13,9 @@ class Select:
     def __init__(
         self,
         name: str,
-        options: list[SELECT_TYPES],
+        options: List[SELECT_TYPES],
         default: SELECT_TYPES,
-        input_updates: dict[str, Any] = {},
+        input_updates: Dict[str, Any] = {},
     ):
         self.input_name = name
         self.options = options
@@ -53,4 +55,4 @@ class SelectComponentInfo:
     value: Union[
         int, float, str, bool
     ]  # This can represent the default user supplied value
-    options: list[Any]
+    options: List[Any]
