@@ -2,7 +2,9 @@ import ast
 import io
 import json
 import logging
+import pathlib
 import secrets
+import sys
 from _ast import Assign
 from _ast import Attribute
 from _ast import Call
@@ -182,6 +184,8 @@ class AddHexPrefixForCharts(ast.NodeTransformer):
 
 
 def run_script(script_name, input_updates, hex_token_generator):
+    script_dir = str(pathlib.Path(script_name).parent)
+
     with open(script_name) as f:
         lines = f.read()
         user_code = ast.parse(lines, script_name)
@@ -222,7 +226,10 @@ def run_script(script_name, input_updates, hex_token_generator):
         logger.debug(ast.unparse(user_code))
         logger.debug('\n----------------------------\n\n')
 
+        # Add path and then pop later to handle relative imports within the user script.
+        sys.path.append(script_dir)
         exec(compile(user_code, script_name, "exec"), locals_copy, locals_copy)
+        sys.path.remove(script_dir)
 
         raster_reference_payload = locals_copy.get("gpo_raster_reference_payload", None)
 
